@@ -44,6 +44,7 @@ namespace Breeze
         // setup default geometry
         const int height = decoration->buttonHeight();
         setGeometry(QRect(0, 0, height, height));
+        setIconSize(QSize( height, height ));
 
         // connections
         connect(decoration->client().data(), SIGNAL(iconChanged(QIcon)), this, SLOT(update()));
@@ -126,12 +127,14 @@ namespace Breeze
         if( m_flag == FlagFirstInList ) painter->translate( m_offset );
         else painter->translate( 0, m_offset.y() );
 
+        if( !m_iconSize.isValid() ) m_iconSize = geometry().size().toSize();
+
+        // menu button
         if (type() == KDecoration2::DecorationButtonType::Menu)
         {
 
-            const QSizeF iconSize( size().width()-m_offset.x(), size().height()-m_offset.y() );
-            const QRectF iconRect( geometry().topLeft(), iconSize );
-            const QPixmap pixmap = decoration()->client().data()->icon().pixmap( iconSize.toSize());
+            const QRectF iconRect( geometry().topLeft(), m_iconSize );
+            const QPixmap pixmap = decoration()->client().data()->icon().pixmap( m_iconSize );
             painter->drawPixmap(iconRect.center() - QPoint(pixmap.width()/2, pixmap.height()/2), pixmap);
 
         } else {
@@ -157,7 +160,7 @@ namespace Breeze
         */
         painter->translate( geometry().topLeft() );
 
-        const qreal width( geometry().width() - m_offset.x() );
+        const qreal width( m_iconSize.width() );
         painter->scale( width/20, width/20 );
         painter->translate( 1, 1 );
 
@@ -179,7 +182,7 @@ namespace Breeze
             QPen pen( foregroundColor );
             pen.setCapStyle( Qt::RoundCap );
             pen.setJoinStyle( Qt::MiterJoin );
-            pen.setWidthF( 1.1*qMax(1.0, 20/width ) );
+            pen.setWidthF( 1.1*qMax((qreal)1.0, 20/width ) );
 
             painter->setPen( pen );
             painter->setBrush( Qt::NoBrush );
