@@ -80,6 +80,10 @@ namespace Breeze
         void setVerticalOffset( qreal value )
         { m_offset.setY( value ); }
 
+        //* set icon size
+        void setIconSize( const QSize& value )
+        { m_iconSize = value; }
+
         //*@name active state change animation
         //@{
         void setOpacity( qreal value )
@@ -124,6 +128,9 @@ namespace Breeze
         //* vertical offset (for rendering)
         QPointF m_offset;
 
+        //* icon size
+        QSize m_iconSize;
+
         //* active state change opacity
         qreal m_opacity = 0;
     };
