@@ -96,6 +96,7 @@ namespace Breeze
         inline bool isMaximized( void ) const;
         inline bool isMaximizedHorizontally( void ) const;
         inline bool isMaximizedVertically( void ) const;
+        inline bool hideTitleBar( void ) const;
         //@}
 
         public Q_SLOTS:
@@ -107,9 +108,12 @@ namespace Breeze
         void updateButtonsGeometry();
         void updateTitleBar();
         void updateAnimationState();
+        void updateSizeGripVisibility();
 
         private:
-        QRect captionRect() const;
+
+        //* return the rect in which caption will be drawn
+        QPair<QRect,Qt::Alignment> captionRect( void ) const;
 
         void createButtons();
         void paintTitleBar(QPainter *painter, const QRect &repaintRegion);
@@ -164,6 +168,7 @@ namespace Breeze
     bool Decoration::isMaximized( void ) const { return client().data()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows(); }
     bool Decoration::isMaximizedHorizontally( void ) const { return client().data()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows(); }
     bool Decoration::isMaximizedVertically( void ) const { return client().data()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows(); }
+    bool Decoration::hideTitleBar( void ) const { return m_internalSettings->hideTitleBar() && !client().data()->isShaded(); }
 
 }
 
